# Usage

Datamol has been designed to be used with a single import:

```python
import datamol as dm
```

All `datamol` functions are available under `dm`.

## Available modules

- `dm`: top-level module that contains common functions.
- `dm.actions`: functions to edit molecules.
- `dm.conformers`: generate and perform computation on conformers.
- `dm.data`: get some common data (mainly for dev purposes).
- `dm.fragment`: fragment molecules in a list of fragments.
- `dm.reactions`: functions to work with reactions.
- `dm.scaffold`: get representative scaffolds from a list of molecules.
- `dm.viz`: 2D/3D visualization functions.
